@@ -6,18 +6,28 @@
 #' @import shinydashboard
 #' @import markdown
 #' @importFrom shiny NS tagList 
+#' @importFrom shinyjs extendShinyjs useShinyjs
 #' @noRd
 app_ui <- function(request) {
   tagList(
     # Leave this function for adding external resources
     golem_add_external_resources(),
+    
     # Your application UI logic 
     dashboardPage(
       dashboardHeader(disable = TRUE),
       dashboardSidebar(disable = TRUE),
       dashboardBody(
         # Lab colors
-        tags$head(tags$style(HTML('
+        tags$head(
+          tags$style(
+            HTML('
+         a.action-button {
+                color: #6c81c0;
+         }
+         a.action-button.red {
+                color: #6c81c0;
+         }
         .navbar-static-top {background-color: green;}
         
         .navbar-default .navbar-nav>.active>a {background-color: green;}
@@ -25,56 +35,71 @@ app_ui <- function(request) {
         .body {
             background-color: #22284c;
         }
+        
+        .box {margin-bottom: 40px;}
+                                  
+        .box.box-solid > .box-header > .box-tools .btn {
+           position: relative;
+           bottom: 5px;
+           box-shadow: none;
+        }
+        
+        .box.box-solid.box-primary > .box-header a,
+        .box.box-solid.box-primary > .box-header .btn {
+            color: #ffffff;
+        }
                               
         .box.box-solid.box-primary>.box-header {
+          height: 50px;
           color:#fff;
           background:#6c81c0
-                            }
+        }
         
         .box.box-solid.box-primary{
-        border-bottom-color:#6c81c0;
-        border-left-color:#6c81c0;
-        border-right-color:#6c81c0;
-        border-top-color:#6c81c0;
+          border-bottom-color:#6c81c0;
+          border-left-color:#6c81c0;
+          border-right-color:#6c81c0;
+          border-top-color:#6c81c0;
         }
         
         .box.box-solid.box-info>.box-header {
-        color:#fff;
-        background:#22284c
+          height: 50px;
+          color:#fff;
+          background:#22284c
         }
         
         .box.box-solid.box-info{
-        border-bottom-color:#22284c;
-        border-left-color:#22284c;
-        border-right-color:#22284c;
-        border-top-color:#22284c;
+          border-bottom-color:#22284c;
+          border-left-color:#22284c;
+          border-right-color:#22284c;
+          border-top-color:#22284c;
         }
         
         .box.box-solid.box-warning>.box-header {
-        color:#fff;
-        background:#a91021ff
+          color:#fff;
+          background:#a91021ff
         }
         
         .box.box-solid.box-warning{
-        border-bottom-color:#a91021ff;
-        border-left-color:#a91021ff;
-        border-right-color:#a91021ff;
-        border-top-color:#a91021ff;
+          border-bottom-color:#a91021ff;
+          border-left-color:#a91021ff;
+          border-right-color:#a91021ff;
+          border-top-color:#a91021ff;
         }
                               '))),
+        tags$head(tags$style(HTML('.navbar-static-top {background-color: #22284c;}',
+                                  '.navbar-default .navbar-nav>.active>a {background-color: #22284c;}'))),
         fluidPage(
-          navbarPage( 
-            tags$script(HTML("var header = $('.navbar > .container-fluid');
-header.append('<div style=\"float:right\"><a href=\"https://www.polyploids.org/\"><img src=\"www/logo_white.png\" alt=\"alt\" style=\"float:right;width:120px;height:80px;padding-top:10px;padding-bottom:10px;\"> </a>`</div>');
-    console.log(header)")
-            ),
+          navbarPage(
             title =  "VIEWpoly", 
             id = "viewpoly",
             theme = shinythemes::shinytheme("flatly"),  # <--- Specify theme here
-            tags$head(tags$style(HTML('.navbar-static-top {background-color: #22284c;}',
-                                      '.navbar-default .navbar-nav>.active>a {background-color: #22284c;}'))),
-            tabPanel("About",
-                     includeMarkdown(system.file("ext", "about.Rmd", package = "viewpoly"))
+            tabPanel("About", value = "about",
+                     includeMarkdown(system.file("ext", "about.Rmd", package = "viewpoly")),
+                     tags$script(HTML("var header = $('.navbar > .container-fluid');
+header.append('<div style=\"float:right\"><a href=\"https://www.polyploids.org/\"><img src=\"www/logo_white.png\" alt=\"alt\" style=\"float:right;width:120px;height:80px;padding-top:10px;padding-bottom:10px;\"> </a>`</div>');
+    console.log(header)")
+                     ),
             ),
             tabPanel("Input data", value = "upload",
                      mod_upload_ui("upload_ui_1")),
@@ -115,4 +140,3 @@ golem_add_external_resources <- function(){
     # for example, you can add shinyalert::useShinyalert() 
   )
 }
-
